@@ -8,7 +8,11 @@ from telegram_util import matchKey
 def isCaption(item):
 	if not item:
 		return False
-	return 'caption' in str(item.attrs).lower() and item.name != 'img'
+	if 'caption' in str(item.attrs).lower() and item.name != 'img':
+		return True
+	if 'img-title' in str(item.attrs).lower() and item.name != 'img':
+		return True
+	return False
 
 def _getCaption(item):
 	if isCaption(item.find_next()):
@@ -17,7 +21,7 @@ def _getCaption(item):
 	if not parent:
 		return
 	for x in parent.find_all():
-		if 'caption' in str(x.attrs).lower() and x.name != 'img':
+		if isCaption(x):
 			return x
 
 def _formatImgUrl(raw, domain):
@@ -106,6 +110,11 @@ def _yieldPossibleImg(soup):
 		for x in l:
 			yield x
 
+def getCaptionText(item):
+	if not item.text:
+		return ''
+	return item.text.split('圖／')[0].strip()
+
 def _cleanupImages(soup, domain):
 	for img in soup.find_all("div", class_="js-delayed-image-load"):
 		img.name = 'img'
@@ -141,7 +150,7 @@ def _cleanupImages(soup, domain):
 		raw_caption = _getCaption(img)
 		if raw_caption:
 			caption = fact().new_tag("figcaption")
-			caption.append(_copyB(raw_caption))
+			caption.append(getCaptionText(raw_caption))
 		figure = fact().new_tag("figure")
 		figure.append(_copyB(img))
 		
