@@ -11,13 +11,13 @@ def _seemsValidRawArticle(soup, text_limit = 500):
 
 def getMatters(soup):
 	main = soup.find("div", class_ = "u-content")
-	try:
-		item = main.parent.parent.parent.parent.findNext('p')
-	except:
-		return main
-	while item:
-		main.insert(len(main.contents), item)
-		item = item.findNext('p')
+	# try:
+	# 	item = main.parent.parent.parent.parent.findNext('p')
+	# except:
+	# 	return main
+	# while item:
+	# 	main.insert(len(main.contents), item)
+	# 	item = item.findNext('p')
 	return main
 
 def getUdn(soup):
@@ -64,6 +64,7 @@ def _getInnerArticle_(soup, domain):
 		lambda x: x.find("div", class_ = "info-content"),
 		lambda x: x.find("main", class_ = "info-content"),
 		lambda x: x.find("div", class_ = "post__contentWrap"),
+		lambda x: x.find("div", class_ = "u-content"),
 	]
 	domain_specific_applicators = {
 		'': [lambda x: x.find("body")],
@@ -94,7 +95,7 @@ def _getInnerArticle_(soup, domain):
 		'allnow.com': [lambda x: x.find("div", id = 'article-content'),],
 		'news.rthk.hk': [lambda x: x.find("div", class_ = 'itemFullText'),],
 	}
-	if 'matters.news' in domain:
+	if 'matters.town' in domain:
 		return getMatters(soup)
 	if 'opinion.udn.com' in domain:
 		return getUdn(soup)
