@@ -10,7 +10,7 @@ import sys
 OFFTOPIC_TAG = ['small', 'address', 'meta', 'script', 'sup', 'svg']
 
 OFFTOPIC_ATT = [
-	'latest', 'more', 'facebook', 'ts-fab-wrapper',
+	'teaserContentWrap', 'artikel', 'latest', 'more', 'facebook', 'ts-fab-wrapper',
 	'cn-carousel-medium-strip', 'video__end-slate__top-wrapper', 'metadata', 
 	'el__article--embed', 'signup', 'related', 'disclaimer', 'off-screen', 
 	'story-body__unordered-list', 'story-image-copyright', 'article-header', 
@@ -32,8 +32,8 @@ OFFTOPIC_ATT = [
 	'field-photo-credit', 'Avatar', 'floating-share', 'meta-box', 'tag-list',
 	'tools__ShareIconBlock', 'aside__Container', 'MetadataAndTool', 'DesktopAsideBlock',
 	'StyledSeparationCurve', 'separation-curve', "['extending']", "['meta-tag']",
-	'sharedaddy', 'ArticleTags_root', 'imgWrap__nav'
-
+	'sharedaddy', 'ArticleTags_root', 'imgWrap__nav', 'elementor-location-header', 
+	'elementor-post-navigation', 'elementor-location-popup', 'article/support/request'
 ]
 
 OFFTOPIC_ATT_WITH_EXCEPTION = {
@@ -64,7 +64,8 @@ P_AD_WORDS = [
 	'discounted subscription today',
 	'Just follow this link',
 	'Share on WeChat / 在微信上分享这篇文章',
-	'English version / 英文翻译'
+	'English version / 英文翻译',
+	'2023年德国之声版权声明',
 ]
 
 def _isOffTopic(attrs):
@@ -72,7 +73,7 @@ def _isOffTopic(attrs):
 		return 
 	r = []
 	for k, v in attrs.items():
-		if k != 'data-component' and matchKey(k, ['href', 'src', 'url', 'alt', 'data', 'xmlns:fb']):
+		if k not in ['data-component', 'data-test-id'] and matchKey(k, ['href', 'src', 'url', 'alt', 'data', 'xmlns:fb']):
 			continue
 		r.append(str(k) + ' : ' + str(v))
 	r = '\n'.join(r)
@@ -107,6 +108,8 @@ def _decompseAds(soup):
 			_decompose(item)
 		if 'align=' in str(item) and 'right' in str(item) and item.text and item.text.startswith('文：'):
 			_decompose(item)
+		if item.parent and "['picBox', 'full', 'rechts']" in str(item.parent.attrs):
+			_decompose(item)
 
 def _decomposeOfftopic(soup, url, args = {}):
 	for item in list(soup.find_all())[1:]:
